summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/redclash.c
diff options
context:
space:
mode:
author Aaron Giles <aaron@aarongiles.com>2012-01-14 00:39:13 +0000
committer Aaron Giles <aaron@aarongiles.com>2012-01-14 00:39:13 +0000
commit8d1ffc9677f513da4bda481dd2e5d67021043479 (patch)
tree98e70b854ac2cddae2ed2b2182da18df91ffd069 /src/mame/video/redclash.c
parente325b867ece9738594a92d7f75cc45168fdac494 (diff)
Death to SCREEN_EOF, which was ambiguously called either
at the start or end of VBLANK depending on the video flag VIDEO_UPDATE_AFTER_VBLANK. Replaced with SCREEN_VBLANK callbacks which are called both at the start and end of VBLANK, so you can operate either way, and be explicit about it. Updated all callers. Also updated screen_device to use device timers and some other minor cleanups.
Diffstat (limited to 'src/mame/video/redclash.c')
-rw-r--r--src/mame/video/redclash.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/mame/video/redclash.c b/src/mame/video/redclash.c
index f167c0f1a02..0fcff897ce8 100644
--- a/src/mame/video/redclash.c
+++ b/src/mame/video/redclash.c
@@ -315,7 +315,7 @@ void redclash_set_stars_enable( running_machine &machine, UINT8 on )
}
/* This sets up which starfield to draw and the offset, */
/* To be called from SCREEN_EOF() */
void redclash_update_stars_state( running_machine &machine )
{
@@ -418,9 +418,11 @@ void redclash_draw_stars( running_machine &machine, bitmap_ind16 &bitmap, const
}
}
-SCREEN_EOF( redclash )
+SCREEN_VBLANK( redclash )
{
- redclash_update_stars_state(screen.machine());
+ // rising edge
+ if (vblank_on)
+ redclash_update_stars_state(screen.machine());
}
SCREEN_UPDATE_IND16( redclash )
@@ -315,7 +315,7 @@ void redclash_set_stars_enable( running_machine &machine, UINT8 on )
}
/* This sets up which starfield to draw and the offset, */
-/* To be called from SCREEN_EOF() */
+/* To be called from SCREEN_VBLANK() */
void redclash_update_stars_state( running_machine &machine )
{